/****************************************************************************
** Meta object code from reading C++ file 'tooltipexample.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.18)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../examples/collections/tooltipexample.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'tooltipexample.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.18. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_ToolTipExampleWindow_t {
    QByteArrayData data[1];
    char stringdata0[21];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_ToolTipExampleWindow_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_ToolTipExampleWindow_t qt_meta_stringdata_ToolTipExampleWindow = {
    {
QT_MOC_LITERAL(0, 0, 20) // "ToolTipExampleWindow"

    },
    "ToolTipExampleWindow"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_ToolTipExampleWindow[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void ToolTipExampleWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject ToolTipExampleWindow::staticMetaObject = { {
    QMetaObject::SuperData::link<PageWindowInterface::staticMetaObject>(),
    qt_meta_stringdata_ToolTipExampleWindow.data,
    qt_meta_data_ToolTipExampleWindow,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *ToolTipExampleWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ToolTipExampleWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_ToolTipExampleWindow.stringdata0))
        return static_cast<void*>(this);
    return PageWindowInterface::qt_metacast(_clname);
}

int ToolTipExampleWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = PageWindowInterface::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_DToolTipExample_t {
    QByteArrayData data[1];
    char stringdata0[16];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_DToolTipExample_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_DToolTipExample_t qt_meta_stringdata_DToolTipExample = {
    {
QT_MOC_LITERAL(0, 0, 15) // "DToolTipExample"

    },
    "DToolTipExample"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_DToolTipExample[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void DToolTipExample::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject DToolTipExample::staticMetaObject = { {
    QMetaObject::SuperData::link<ExampleWindowInterface::staticMetaObject>(),
    qt_meta_stringdata_DToolTipExample.data,
    qt_meta_data_DToolTipExample,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *DToolTipExample::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DToolTipExample::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_DToolTipExample.stringdata0))
        return static_cast<void*>(this);
    return ExampleWindowInterface::qt_metacast(_clname);
}

int DToolTipExample::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ExampleWindowInterface::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_DArrowRectangleExample_t {
    QByteArrayData data[1];
    char stringdata0[23];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_DArrowRectangleExample_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_DArrowRectangleExample_t qt_meta_stringdata_DArrowRectangleExample = {
    {
QT_MOC_LITERAL(0, 0, 22) // "DArrowRectangleExample"

    },
    "DArrowRectangleExample"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_DArrowRectangleExample[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void DArrowRectangleExample::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject DArrowRectangleExample::staticMetaObject = { {
    QMetaObject::SuperData::link<ExampleWindowInterface::staticMetaObject>(),
    qt_meta_stringdata_DArrowRectangleExample.data,
    qt_meta_data_DArrowRectangleExample,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *DArrowRectangleExample::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DArrowRectangleExample::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_DArrowRectangleExample.stringdata0))
        return static_cast<void*>(this);
    return ExampleWindowInterface::qt_metacast(_clname);
}

int DArrowRectangleExample::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ExampleWindowInterface::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
